#!/bin/zsh

# set to "" to turn off debug output
#d="1"
d=""

# urlviewer.sh - try hard to display a URL
#
# Changes:
#
# 040110 sw  complete revamp, add konqueror support via dcop
# 050307 sw  add firefox (from /usr/bin), avoid running lynx *and* other
# 060511 sw  version for local package on SL4 (maybe SL3 later on)
#
# This script will accept a URL as its sole argument and try its very best
# to display it in the user's preferred browser:
#
# o if mozilla is accepting remote connections, use it
# o next, try konqueror via DCOP (only if an HTML widget is already open)
# o next, try netscape 4 (in DL5, then DL4 location)
# o next, if WWW_BROWSER is set to a web browser, start this
# o as a last resort, or if X is not available, use lynx
#
# note that netscape4 is known to be unreliable under KDE on DL5

# no X - only option is lynx
if [ -z "$DISPLAY" ]; then 
    echo "DISPLAY not set - using lynx"
    exec lynx $1
fi

# how about firefox ?
if [ -x /usr/bin/firefox ]; then
    [ $d ] && echo -n "trying /usr/bin/firefox..."
    /usr/bin/firefox -remote "ping()" >/dev/null 2>&1
    if [ $? -eq 0 ]; then
	[ $d ] && echo "ping successful - trying mozilla -remote"
	/usr/bin/firefox -remote "OpenURL($1,new-tab)" >/dev/null 2>&1
	if [ $? -eq 0 ]; then
	    [ $d ] && echo "  success"
	    exit 0
	else
	    [ $d ] && echo "  failed!"
	fi
    else
	[ $d ] && echo "  ping failed"
    fi
fi

# how about mozilla ?
if [ -x /usr/bin/mozilla ]; then
    [ $d ] && echo -n "trying /usr/bin/mozilla..."
    /usr/bin/mozilla -remote "ping()" >/dev/null 2>&1
    if [ $? -eq 0 ]; then
	[ $d ] && echo "ping successful - trying mozilla -remote"
	/usr/bin/mozilla -remote "OpenURL($1,new-tab)" >/dev/null 2>&1
	if [ $? -eq 0 ]; then
	    [ $d ] && echo "  success"
	    exit 0
	else
	    [ $d ] && echo "  failed!"
	fi
    else
	[ $d ] && echo "  ping failed"
    fi
fi

# the test on KDE/konqueror fails fairly qulickly, so we do it 1st:
dcop 2>&1 | grep -v ERROR >/dev/null 2>&1
if [ $? -eq 0 ]; then
    [ $d ] && echo "trying konqueror via DCOP"
    for i in `dcop konqueror-\*`; do
	[ $d ] && echo "  trying $i"
	dcop $i | grep html-widget >/dev/null 2>&1
	if [ $? -eq 0 ]; then
	    [ $d ] &&echo "    has html-widget"
	    for j in `dcop $i | grep konqueror-mainwindow`; do
		[ $d ] && echo "    trying $j"
		n=`dcop $i $j viewCount` >/dev/null 2>&1
		if [ $? -eq 0 -a "$n" -ne 0 ]; then
		    [ $d ] &&echo "      has views - trying to use it"
		    dcop $i $j openURL $1
		    if [ $? -eq 0 ]; then
			[ $d ] && echo "        success"
			exit 0
		    else
			[ $d ] && echo "        failed"
		    fi
		else
		    [ $d ] &&echo "      has no views"
		fi
	    done
	else
	    [ $d ] &&echo "    has no html-widget"
	fi
    done
fi

# maybe user expressed his preference, otherwise set it to something usable:
if [ -z "$WWW_BROWSER" ]; then
    if [ -x /usr/bin/firefox ]; then
	WWW_BROWSER="/usr/bin/firefox"
    elif [ -x /usr/bin/mozilla ]; then
	WWW_BROWSER="/usr/bin/mozilla"
    fi
fi

# try starting a new browser
if [ -n "$WWW_BROWSER" ]; then
    whence "$WWW_BROWSER" >/dev/null && {
	[ $d ] && echo "WWW_BROWSER set to $WWW_BROWSER - trying this"
	nohup "$WWW_BROWSER" $1 >/dev/null 2>&1 &
	exit 0
    }
fi

# nothing else worked - last resort
[ $d ] && echo "last resort: lynx"

exec lynx $1
